Replace use of `TRIG_WAKE_EOS` command flag with the new name
`CMDF_WAKE_EOS`.  The numeric value is the same.

Signed-off-by: Ian Abbott <abbo...@mev.co.uk>
---
 drivers/staging/comedi/drivers/ni_labpc_common.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/staging/comedi/drivers/ni_labpc_common.c 
b/drivers/staging/comedi/drivers/ni_labpc_common.c
index 5238a98..1881510 100644
--- a/drivers/staging/comedi/drivers/ni_labpc_common.c
+++ b/drivers/staging/comedi/drivers/ni_labpc_common.c
@@ -689,13 +689,13 @@ static int labpc_ai_cmd(struct comedi_device *dev, struct 
comedi_subdevice *s)
        /* figure out what method we will use to transfer data */
        if (labpc_have_dma_chan(dev) &&
            /* dma unsafe at RT priority,
-            * and too much setup time for TRIG_WAKE_EOS */
-           (cmd->flags & (TRIG_WAKE_EOS | CMDF_PRIORITY)) == 0)
+            * and too much setup time for CMDF_WAKE_EOS */
+           (cmd->flags & (CMDF_WAKE_EOS | CMDF_PRIORITY)) == 0)
                xfer = isa_dma_transfer;
        else if (/* pc-plus has no fifo-half full interrupt */
                 board->is_labpc1200 &&
                 /* wake-end-of-scan should interrupt on fifo not empty */
-                (cmd->flags & TRIG_WAKE_EOS) == 0 &&
+                (cmd->flags & CMDF_WAKE_EOS) == 0 &&
                 /* make sure we are taking more than just a few points */
                 (cmd->stop_src != TRIG_COUNT || devpriv->count > 256))
                xfer = fifo_half_full_transfer;
-- 
2.1.0

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to